# ua-parser module

Project page: https://drupal.org/project/uaparser

This module integrates Drupal 8 with **ua-parser**, an open-source and community-driven,
regexp-based user-agent parser. 

For more information about ua-parser, visit [uaparser.org](http://www.uaparser.org/).


## Requirements

The module uses *Composer* to get its dependencies; installation instructions below assume
that the [Composer Manager](https://www.drupal.org/project/composer_manager) module is installed and active. If you have a different Composer
workflow, then you probably do not need instructions anyway :)


## Installing

1. Download and install the module as usual, see the [official documentation](https://www.drupal.org/documentation/install/modules-themes/modules-8)
for further information.
2. Execute `composer drupal-update` from the Drupal root directory.


## Configuration

- Go to _Manage > Configuration > System > ua-parser_ and update the user-agent definition
  file to the most recent version by clicking on the 'Update now' button.
- Select the 'Enable automatic updates' tickbox if you want automatic updates of the file,
  and the frequency of the updates.
- The 'USER-AGENT LOOKUP' part of the form allows to parse any user-agent string and display
  its results. By default it displays the results of the current request's user-agent string,
  but any string can be copy/pasted in the text field, and results displayed clicking on the
  'Lookup' button.


## Usage

The module by itself does not do much - it exposes a service that can be used to parse
user-agent strings and return meaningful results. All the work is done by the _ua-parser/uap-php_
library that the service integrates with.
The service however allows to cache user-agent strings and its results in a Drupal cache bin,
to speed up lookups.
Also the service manages updates of the user-agent definition file from the source.

Basic code example:

```php
$parser = \Drupal::service('uaparser');
$parsed_ua = $parser->parse('Mozilla/5.0 (Windows NT 6.2; WOW64; rv:35.0) Gecko/20100101 Firefox/35.0');
return ['#markup' => $parsed_ua['client']->toString()];
```

will return
```
Firefox 35.0/Windows 8
```

## Other modules

The [Browscap](https://www.drupal.org/project/browscap) module provides similar functionality.


