<?php

namespace Drupal\uaparser\Tests;

use Drupal\simpletest\WebTestBase;

/**
 * Tests ua-parser functionality.
 *
 * @group ua-parser
 */
class UaparserTest extends WebTestBase {

  protected $uaParserAdmin = 'admin/config/system/uaparser';
  protected $parser;

  public static $modules = ['uaparser'];

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();
    $this->parser = $this->container->get('uaparser');
    $this->drupalLogin($this->drupalCreateUser([
      'administer site configuration',
    ]));
  }

  /**
   * Tests ua-parser functionality.
   */
  public function testUaParser() {
    $this->drupalGet($this->uaParserAdmin);

    $ua = "Mozilla/5.0 (Windows NT 6.3; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/49.0.2623.110 Safari/537.36";

    // Check both client and parser time are returned.
    $res = $this->parser->parse($ua);
    $this->assertTrue(isset($res['client']));
    $this->assertTrue(isset($res['time']));

    // After caching, check only client info is returned.
    $res = $this->parser->parse($ua);
    $this->assertTrue(isset($res['client']));
    $this->assertFalse(isset($res['time']));

    // Update definition file, cache should be cleared.
    $this->parser->update();
    $res = $this->parser->parse($ua);
    $this->assertTrue(isset($res['client']));
    $this->assertTrue(isset($res['time']));
  }

}
